@@ -1638,7 +1638,16 @@ cpl_error_code qmost_ffdiv_fib(
             memcpy(naxis, bnaxis, sizeof(naxis));
         }
     }
-            
+
+    if(naxis[0] != nx) {
+        TIDY;
+        return cpl_error_set_message(cpl_func, CPL_ERROR_INCOMPATIBLE_INPUT,
+                                     "input 2D spectrum and fibre flat "
+                                     "wavelength axis "
+                                     "doesn't match: %ld != %ld",
+                                     nx, naxis[0]);
+    }
+
     /* Loop for each spectrum. Do nothing if the fibre is dead */
 
     for (i = 1; i <= ny; i++) {
