@@ -166,6 +166,7 @@ cpl_error_code qmost_fibtabload (
     char *key = NULL;
     cpl_errorstate prestate;
     int shut_open, min_pos, nsimucal = 0, isnull, fib_st;
+    int slit_pos;
 
 #undef TIDY
 #define TIDY                                    \
@@ -550,6 +551,58 @@ cpl_error_code qmost_fibtabload (
             }
         }
 
+        /* Special case to detect off by one error in raw files.
+         * This happened because the number and layout of fibres on
+         * the spectrograph slit was changed going from simulated to
+         * real data, but the raw file metadata were not updated to
+         * reflect this change. */
+        if(nsimucal == 5) {
+            /* For real data, this is incorrect, there are actually 6.
+             * The entries for HRS and LRS-B are also reversed.  This
+             * kludge fixes the problems by renumbering the column.
+             * CAUTION: this is backwards-incompatible, and will
+             * break any data sets where the number of simucals should
+             * actually be 5, such as simulated data. */
+            cpl_msg_warning(cpl_func,
+                            "SLIT_POS numbering error detected. "
+                            "Applying workaround.");
+
+            nrowstmp = cpl_table_get_nrow(shuftab);
+
+            for(row = 0; row < nrowstmp; row++) {
+                slit_pos = cpl_table_get_int(shuftab,
+                                             "SLIT_POS",
+                                             row,
+                                             &isnull);
+                if(isnull < 0) {
+                    TIDY;
+                    return cpl_error_set_message(cpl_func,
+                                                 cpl_error_get_code(),
+                                                 "could not read %s "
+                                                 "for row %d",
+                                                 "SLIT_POS", row);
+                }
+                else if(isnull == 0 && slit_pos != 0) {
+                    if(shuffle == QMOST_SPEC_LRS_A) {
+                        /* Add 1 for LRS-A */
+                        slit_pos++;
+                    }
+                    else {
+                        /* Equivalent to adding 1 and then reversing
+                         * the numbering for HRS and LRS-B. */
+                        slit_pos = 824 - slit_pos;
+                    }
+
+                    cpl_table_set_int(shuftab,
+                                      "SLIT_POS",
+                                      row,
+                                      slit_pos);
+                }
+            }
+
+            nsimucal++;
+        }
+
         if(nsimucal > 0) {
             /* Figure out if simucal fibres are illuminated using PHDU
              * keywords.  We first check if any of the lamps are on, and
@@ -668,8 +721,8 @@ cpl_error_code qmost_fibtabload (
                 }
             }
 
-            /* Insert blanks for the simucal fibres at end, set FIB_USE=4
-               for calibration, and FIB_ROOT and SLIT_POS to appropriate
+            /* Insert blanks for the simucal fibres at end, set FIB_USE=0
+               for simucal, and FIB_ROOT and SLIT_POS to appropriate
                values. */
             nrowstmp = cpl_table_get_nrow(shuftab);
 
