@@ -712,16 +712,34 @@ static void test_qmost_ffdiv_fib(void)
     cpl_image_delete(dummy_var);
     dummy_var = NULL;
 
-    /* Size mismatch of flat array */
-    dummy_img = cpl_image_new(1, 1, CPL_TYPE_FLOAT);
+    /* Size mismatch of flat array in y */
+    dummy_img = cpl_image_new(1, nspec, CPL_TYPE_FLOAT);
+    dummy_var = cpl_image_new(1, nspec, CPL_TYPE_FLOAT);
 
     code = qmost_ffdiv_fib(spec_img, spec_var, spec_hdr,
-                           trace_tbl, dummy_img, ffnorm_var);
+                           trace_tbl, dummy_img, dummy_var);
     cpl_test_eq_error(code, CPL_ERROR_INCOMPATIBLE_INPUT);
 
     cpl_image_delete(dummy_img);
     dummy_img = NULL;
 
+    cpl_image_delete(dummy_var);
+    dummy_var = NULL;
+
+    /* Size mismatch of flat array in x */
+    dummy_img = cpl_image_new(nwave, 1, CPL_TYPE_FLOAT);
+    dummy_var = cpl_image_new(nwave, 1, CPL_TYPE_FLOAT);
+
+    code = qmost_ffdiv_fib(spec_img, spec_var, spec_hdr,
+                           trace_tbl, dummy_img, dummy_var);
+    cpl_test_eq_error(code, CPL_ERROR_INCOMPATIBLE_INPUT);
+
+    cpl_image_delete(dummy_img);
+    dummy_img = NULL;
+
+    cpl_image_delete(dummy_var);
+    dummy_var = NULL;
+
     /* Size mismatch of flat error array */
     dummy_var = cpl_image_new(1, 1, CPL_TYPE_FLOAT);
 
