@@ -176,33 +176,33 @@ static void test_qmost_fibtabload(void)
     cpl_table_set_int(outtab, "FIB_ID", 0, 1);
     cpl_table_set_int(outtab, "FIB_ROOT", 0, 0);
     cpl_table_set_int(outtab, "FIB_ST", 0, 1);
-    cpl_table_set_int(outtab, "SLIT_POS", 0, 10);
+    cpl_table_set_int(outtab, "SLIT_POS", 0, 11);
     cpl_table_set_int(outtab, "FIB_USE", 0, 1);
 
     /* Fibre 2, wrong root (should get filtered) */
     cpl_table_set_int(outtab, "FIB_ID", 1, 2);
     cpl_table_set_int(outtab, "FIB_ROOT", 1, 2);
     cpl_table_set_int(outtab, "FIB_ST", 1, 2);
-    cpl_table_set_int(outtab, "SLIT_POS", 1, 9);
+    cpl_table_set_int(outtab, "SLIT_POS", 1, 10);
     cpl_table_set_int(outtab, "FIB_USE", 1, 1);
 
     /* Fibres 3-5, okay to test sort */
     cpl_table_set_int(outtab, "FIB_ID", 2, 3);
     cpl_table_set_int(outtab, "FIB_ROOT", 2, 1);
     cpl_table_set_int(outtab, "FIB_ST", 2, 2);
-    cpl_table_set_int(outtab, "SLIT_POS", 2, 8);
+    cpl_table_set_int(outtab, "SLIT_POS", 2, 9);
     cpl_table_set_int(outtab, "FIB_USE", 2, 1);
 
     cpl_table_set_int(outtab, "FIB_ID", 3, 4);
     cpl_table_set_int(outtab, "FIB_ROOT", 3, 1);
     cpl_table_set_int(outtab, "FIB_ST", 3, 1);
-    cpl_table_set_int(outtab, "SLIT_POS", 3, 7);
+    cpl_table_set_int(outtab, "SLIT_POS", 3, 8);
     cpl_table_set_int(outtab, "FIB_USE", 3, 1);
 
     cpl_table_set_int(outtab, "FIB_ID", 4, 5);
     cpl_table_set_int(outtab, "FIB_ROOT", 4, 1);
     cpl_table_set_int(outtab, "FIB_ST", 4, 0);
-    cpl_table_set_int(outtab, "SLIT_POS", 4, 6);
+    cpl_table_set_int(outtab, "SLIT_POS", 4, 7);
     cpl_table_set_int(outtab, "FIB_USE", 4, 1);
 
     outhdr = cpl_propertylist_new();
@@ -230,26 +230,26 @@ static void test_qmost_fibtabload(void)
     hdr = NULL;
 
     /* Now load it with shuffle, we should get the 3 selected rows in
-       the correct order plus the 5 simucal entries at each end.  */
+       the correct order plus 6 simucal entries at each end.  */
     code = qmost_fibtabload(frame, 1, &table, &hdr);
     cpl_test_eq_error(code, CPL_ERROR_NONE);
 
-    cpl_test_eq(cpl_table_get_nrow(table), 13);
+    cpl_test_eq(cpl_table_get_nrow(table), 15);
 
     /* Check simucal */
-    for(i = 0; i < 5; i++) {
+    for(i = 0; i < 6; i++) {
         cpl_test_eq(cpl_table_get_int(table, "FIB_USE", i, NULL), 0);
         cpl_test_eq(cpl_table_get_int(table, "FIB_ROOT", i, NULL), 1);
         cpl_test_eq(cpl_table_get_int(table, "SLIT_POS", i, NULL), i+1);
     }
 
     /* Check real fibres */
-    cpl_test_eq(cpl_table_get_int(table, "SLIT_POS", 5, NULL), 6);
     cpl_test_eq(cpl_table_get_int(table, "SLIT_POS", 6, NULL), 7);
     cpl_test_eq(cpl_table_get_int(table, "SLIT_POS", 7, NULL), 8);
+    cpl_test_eq(cpl_table_get_int(table, "SLIT_POS", 8, NULL), 9);
 
     /* Check simucal */
-    for(i = 8; i < 13; i++) {
+    for(i = 9; i < 15; i++) {
         cpl_test_eq(cpl_table_get_int(table, "FIB_USE", i, NULL), 0);
         cpl_test_eq(cpl_table_get_int(table, "FIB_ROOT", i, NULL), 1);
         cpl_test_eq(cpl_table_get_int(table, "SLIT_POS", i, NULL), i+1);
@@ -288,9 +288,9 @@ static void test_qmost_fibtabload(void)
     code = qmost_fibtabload(frame, 1, &table, &hdr);
     cpl_test_eq_error(code, CPL_ERROR_NONE);
 
-    cpl_test_eq(cpl_table_get_nrow(table), 13);
+    cpl_test_eq(cpl_table_get_nrow(table), 15);
 
-    cpl_test_eq(cpl_table_get_int(table, "TEST", 7, NULL), 42);
+    cpl_test_eq(cpl_table_get_int(table, "TEST", 8, NULL), 42);
 
     cpl_table_delete(table);
     table = NULL;
